@@ -175,23 +175,18 @@ def get_property_index(property_line, property_order, line_number):
     # returns immediately with the provided property order
     if len(property_line_splitted) < 2: return len(property_order)
 
-    # in case the length of the splitted line is greater than
-    # expected print a warning message indicating the problem
-    if len(property_line_splitted) > 2:
-        # warns about the extra values in the line and then returns
-        # with the length of the property order
-        extra.warn("Extra values found at line %d" % line_number)
-
     # runs a second split operation that limits the number of splits
     # in the line to two so that no extra problems are raised and then
     # retrieves the name of the current property
     property_line_splitted = property_line.split(":", 1)
-    property_name, _property_value = property_line_splitted
+    property_name, property_value = property_line_splitted
     property_name = property_name.strip()
+    property_value = property_value.strip()
 
-    # in case the property name is empty, raises an exception indicating
+    # in case the property name or value are empty, raises an exception indicating
     # the problem to be handled at the top layers
     if not property_name: raise Exception("property name is empty")
+    if not property_value: raise Exception("property value is empty")
 
     # in case the property is not in the order
     if not property_name in property_order:
@@ -203,6 +198,13 @@ def get_property_index(property_line, property_order, line_number):
         )
         return len(property_order)
 
+    # in case the property value starts with a separator it's considered
+    # that the value is a extra/duplicated separator
+    if property_value[0] == ":":
+        # warns about the extra values in the line, so that the duplicated
+        # information may be properly removed and considered
+        extra.warn("Extra values found at line %d" % line_number)
+
     # determines the index for the property name and returns
     # the value to the caller method
     property_index = property_order.index(property_name)
@@ -543,28 +545,43 @@ def cleanup_properties(
         )
 
         # in case the line contains a single line comment
-        if "/*" in line and "*/" in line:
+        if "/*" in line and "*/" in line and not "*/*/" in line:
             # does nothing, will write the line as is
             pass
-        # in case the line contains a the start of multiline comment
-        elif "/*" in line:
-            # in case the comment mode is already on
-            if comments_started: extra.warn(
-                "Found opening comment inside open comment at line %d" % line_number
-            )
-
-            # increments the comments started counter
-            comments_started += 1
         # in case the line contains the end of multiline comment
         elif "*/" in line:
+            # in case the comment mode is currently not enabled prints
+            # a warning as we're trying to close a comment without opening
             if not comments_started: extra.error(
                 "Found closing comment without corresponding opening at line %d" % line_number
             )
 
+            # in case there's more that one closing comment defined under
+            # the same line prints an error as this is not allowed
+            if line.count("*/") > 1: extra.error(
+                "More that one closing comment at line %d" % line_number
+            )
+
             # decrements the comments started counter and then
             # enables the needs newline flag
-            comments_started -= 1
+            comments_started = 0
             needs_newline = True
+        # in case the line contains a the start of multiline comment
+        elif "/*" in line:
+            # in case the comment mode is already enabled (at least one)
+            # prints a waning about the double opening
+            if comments_started: extra.warn(
+                "Found opening comment inside open comment at line %d" % line_number
+            )
+
+            # in case there's more that one opening comment defined under
+            # the same line prints an error as this is not allowed
+            if line.count("/*") > 1: extra.error(
+                "More that one opening comment at line %d" % line_number
+            )
+
+            # increments the comments started counter
+            comments_started += 1
         # in case this is a comment line
         elif comments_started:
             # does nothing, will just write the line as is
@@ -575,7 +592,7 @@ def cleanup_properties(
             needs_newline = True
         # in case the line contains a full rule specification
         # does nothing, will just write line as is as there's
-        # very few thing possible to optimise under this situation
+        # very few thing possible to optimize under this situation
         elif "{" in line and "}" in line:
             line = line.strip()
             needs_newline = True
